@@ -93,6 +93,7 @@ enum {
     opt_trusted_key,
     opt_try_all_secrets,
     opt_try_secret_key,
+    opt_unwrap,
     opt_use_agent,
     opt_verify,
     opt_verify_options,
@@ -200,6 +201,7 @@ static const int gpg_allowed_options[] = {
     opt_trusted_key,
     opt_try_all_secrets,
     opt_try_secret_key,
+    opt_unwrap,
     opt_use_agent,
     opt_verify,
     opt_verify_options,
@@ -310,6 +312,7 @@ static const struct option gpg_long_options[] = {
     {"trusted-key", 1, 0, opt_trusted_key},
     {"try-secret-key", 1, 0, opt_try_secret_key},
     {"try-all-secrets", 0, 0, opt_try_all_secrets},
+    {"unwrap", 0, 0, opt_unwrap},
     {"use-agent", 0, 0, opt_use_agent},
     {"verify", 0, 0, opt_verify},
     {"verify-options", 1, 0, opt_verify_options},
